@@ -2,11 +2,12 @@
 #ifndef _GTKSOURCEVIEWMM_WRAP_INIT_H
 #define _GTKSOURCEVIEWMM_WRAP_INIT_H
 
-#include <glibmm.h>
+#include <gtkmm/main.h>
 
 /* wrap_init.h
  *
  * Copyright (C) 2005-2006 The gtksourceviewmm development team
+ * Copyright (C) 2010 Krzesimir Nowak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,10 +23,12 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-namespace gtksourceview
+namespace Gsv
 {
-    void wrap_init () ;
-}//end namespace gtksourceview
+  /** Initializes wrapper types.
+   */
+  void wrap_init () ;
+}//end namespace Gsv
 
 #endif //_GTKSOURCEVIEWMM_WRAP_INIT_H
 
